diff --git a/src/org/openstreetmap/josm/data/validation/tests/Addresses.java b/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
index 5b9a350..c10cff7 100644
--- a/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
+++ b/src/org/openstreetmap/josm/data/validation/tests/Addresses.java
@@ -44,6 +44,7 @@ public class Addresses extends Test {
     protected static final String ADDR_INTERPOLATION = "addr:interpolation";
     protected static final String ADDR_STREET        = "addr:street";
     protected static final String ASSOCIATED_STREET  = "associatedStreet";
+    protected static final String ADDR_PLACE         = "addr:place";
     
     protected class AddressError extends TestError {
 
@@ -84,8 +85,8 @@ public class Addresses extends Test {
     @Override
     public void visit(Node n) {
         List<Relation> associatedStreets = getAndCheckAssociatedStreets(n);
-        // Find house number without street (neither addr:street or associatedStreet)
-        if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET)) {
+        // Find house number without street (neither addr:street, associatedStreet or addr:place)
+        if (n.hasKey(ADDR_HOUSE_NUMBER) && !n.hasKey(ADDR_STREET) && !n.hasKey(ADDR_PLACE)) {
             for (Relation r : associatedStreets) {
                 if (r.hasTag("type", ASSOCIATED_STREET)) {
                     return;
